<?php

namespace FiloBlu\AdminSecurity\Helper;

use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Store\Model\ScopeInterface;

class Data extends AbstractHelper
{
    /**
     * @var string
     */
    const LOGIN_FIELD_NAME = 'otp_password';

    /**
     * @var string
     */
    const OTP_EMAIL_TEMPLATE = 'otp_email';

    const ADMIN_SECURITY_ENABLED_PATH = 'filoblu_admin_security/general/filoblu_admin_security_enabled';

    const ADMIN_SECURITY_WHITELIST_ID_PATH = 'filoblu_admin_security/general/filoblu_admin_security_whitelist_ip';

    /**
     * @return bool
     */
    public function adminSecurityIsEnabled()
    {
        return $this->scopeConfig->isSetFlag(self::ADMIN_SECURITY_ENABLED_PATH, ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return mixed
     */
    public function getWhiteListIp()
    {
        return $this->scopeConfig->getValue(self::ADMIN_SECURITY_WHITELIST_ID_PATH, ScopeInterface::SCOPE_STORE);
    }

    /**
     * @param $username
     * @param null $email
     * @param null $ip
     * @param array $otherData
     * @return array
     */
    public function createLogData($username, $email = null, $ip = null, $otherData = [])
    {
        $now = new \DateTime();

        $data = [
            'username' => $username,
            'login_data' => $now->format('Y-m-d H:i:s'),
            'module_name' => $this->_getModuleName()
        ];

        if (!is_null($email)) {
            $data['email'] = $email;
        }

        if (!is_null($ip)) {
            $data['ip_address'] = $ip;
        }

        if (is_array($otherData) && !empty($otherData)) {
            foreach ($otherData as $key => $val) {
                $data[$key] = $val;
            }
        }

        return $data;
    }
}
